@@ -21,7 +21,7 @@
 #include <boost/foreach.hpp>
 #include <boost/algorithm/string/case_conv.hpp>
 
-#include <simgear/debug/logstream.hxx> 
+#include <simgear/debug/logstream.hxx>
 #include <simgear/structure/exception.hxx>
 
 #include <simgear/package/Catalog.hxx>
@@ -29,7 +29,7 @@
 #include <simgear/package/Root.hxx>
 
 namespace simgear {
-    
+
 namespace pkg {
 
 Package::Package(const SGPropertyNode* aProps, CatalogRef aCatalog) :
@@ -103,7 +103,7 @@ bool Package::matches(const SGPropertyNode* aFilter) const
         else
           SG_LOG(SG_GENERAL, SG_WARN, "unknown filter term:" << filter_name);
     } // of filter props iteration
-    
+
     return true;
 }
 
@@ -127,7 +127,7 @@ InstallRef Package::install()
     if (ins) {
         return ins;
     }
-  
+
   // start a new install
     ins = new Install(this, pathOnDisk());
     m_catalog->root()->scheduleToUpdate(ins);
@@ -190,10 +190,10 @@ unsigned int Package::revision() const
     if (!m_props) {
         return 0;
     }
-    
+
     return m_props->getIntValue("revision");
 }
-    
+
 std::string Package::name() const
 {
     return m_props->getStringValue("name");
@@ -203,7 +203,7 @@ size_t Package::fileSizeBytes() const
 {
     return m_props->getIntValue("file-size-bytes");
 }
-  
+
 std::string Package::description() const
 {
     return getLocalisedProp("description");
@@ -213,7 +213,7 @@ string_set Package::tags() const
 {
     return m_tags;
 }
-    
+
 SGPropertyNode* Package::properties() const
 {
     return m_props.ptr();
@@ -225,7 +225,7 @@ string_list Package::thumbnailUrls() const
     if (!m_props) {
         return r;
     }
-    
+
     BOOST_FOREACH(SGPropertyNode* dl, m_props->getChildren("thumbnail")) {
         r.push_back(dl->getStringValue());
     }
@@ -238,20 +238,20 @@ string_list Package::thumbnails() const
     if (!m_props) {
         return r;
     }
-    
+
     BOOST_FOREACH(SGPropertyNode* dl, m_props->getChildren("thumbnail-path")) {
         r.push_back(dl->getStringValue());
     }
     return r;
 }
-    
+
 string_list Package::downloadUrls() const
 {
     string_list r;
     if (!m_props) {
         return r;
     }
-    
+
     BOOST_FOREACH(SGPropertyNode* dl, m_props->getChildren("url")) {
         r.push_back(dl->getStringValue());
     }
@@ -272,41 +272,41 @@ std::string Package::getLocalisedString(const SGPropertyNode* aRoot, const char*
             return localeRoot->getStringValue(aName);
         }
     }
-    
+
     return aRoot->getStringValue(aName);
 }
 
 PackageList Package::dependencies() const
 {
     PackageList result;
-    
+
     BOOST_FOREACH(SGPropertyNode* dep, m_props->getChildren("depends")) {
         std::string depName = dep->getStringValue("id");
         unsigned int rev = dep->getIntValue("revision", 0);
-        
+
     // prefer local hangar package if possible, in case someone does something
     // silly with naming. Of course flightgear's aircraft search doesn't know
     // about hangars, so names still need to be unique.
         PackageRef depPkg = m_catalog->getPackageById(depName);
-        if (!depPkg) {   
+        if (!depPkg) {
             Root* rt = m_catalog->root();
             depPkg = rt->getPackageById(depName);
             if (!depPkg) {
                 throw sg_exception("Couldn't satisfy dependency of " + id() + " : " + depName);
             }
         }
-        
+
         if (depPkg->revision() < rev) {
             throw sg_range_exception("Couldn't find suitable revision of " + depName);
         }
-    
+
     // forbid recursive dependency graphs, we don't need that level
     // of complexity for aircraft resources
         assert(depPkg->dependencies() == PackageList());
-        
+
         result.push_back(depPkg);
     }
-    
+
     return result;
 }
 
@@ -338,6 +338,24 @@ std::string Package::nameForVariant(const std::string& vid) const
     throw sg_exception("Unknow variant +" + vid + " in package " + id());
 }
 
+unsigned int Package::indexOfVariant(const std::string& vid) const
+{
+    if (vid == id()) {
+        return 0;
+    }
+
+    unsigned int result = 1;
+    for (SGPropertyNode* var : m_props->getChildren("variant")) {
+        if (var->getStringValue("id") == vid) {
+            return result;
+        }
+
+        result++;
+    }
+
+    throw sg_exception("Unknow variant " + vid + " in package " + id());
+}
+
 std::string Package::nameForVariant(const unsigned int vIndex) const
 {
     if (vIndex == 0)
@@ -351,6 +369,48 @@ std::string Package::nameForVariant(const unsigned int vIndex) const
     throw sg_exception("Unknow variant in package " + id());
 }
 
+Package::ThumbnailVec Package::thumbnailsForVariant(unsigned int vIndex) const
+{
+    if (vIndex == 0) {
+        return thumbnailsFromProps(m_props);
+    }
+
+    SGPropertyNode_ptr var = m_props->getChild("variant", vIndex - 1);
+    if (!var) {
+        throw sg_exception("Unknow variant in package " + id());
+    }
+
+    return thumbnailsFromProps(var);
+}
+
+Package::Thumbnail::Type thumbnailTypeFromString(const std::string& s)
+{
+    if (s == "exterior") return Package::Thumbnail::Type::EXTERIOR;
+    if (s == "interior") return Package::Thumbnail::Type::INTERIOR;
+    if (s == "panel") return Package::Thumbnail::Type::PANEL;
+    return Package::Thumbnail::Type::UNKNOWN;
+}
+
+Package::Thumbnail::Thumbnail(const std::string& aUrl, const std::string& aPath, Type aType) :
+    url(aUrl),
+    path(aPath),
+    type(aType)
+{
+}
+
+Package::ThumbnailVec Package::thumbnailsFromProps(const SGPropertyNode_ptr& ptr) const
+{
+    ThumbnailVec result;
+
+    for (auto thumbNode : ptr->getChildren("thumbnail")) {
+        Thumbnail t(thumbNode->getStringValue("url"),
+                    thumbNode->getStringValue("path"),
+                    thumbnailTypeFromString(thumbNode->getStringValue("type")));
+        result.push_back(t);
+    }
+
+    return result;
+}
 
 } // of namespace pkg
 
